@@ -84,8 +84,6 @@ impl ConsoleEngine {
     /// Initialize a screen of the provided width and height, and load the target FPS
     pub fn init(width: u32, height: u32, target_fps: u32) -> ConsoleEngine {
         assert!(target_fps > 0, "Target FPS needs to be greater than zero.");
-        let size = crossterm::terminal::size().unwrap();
-        assert!(size.0 as u32 >= width && size.1 as u32 >= height, "Your terminal must have at least a width and height of {}x{} characters. Currently has {}x{}", width, height, size.0, size.1);
         let mut my = ConsoleEngine {
             stdout: stdout(),
             time_limit: std::time::Duration::from_millis(1000 / target_fps as u64),
@@ -100,7 +98,14 @@ impl ConsoleEngine {
             keys_released: vec![],
             mouse_events: vec![],
         };
+        let previous_panic_hook = std::panic::take_hook();
+        std::panic::set_hook(Box::new(move |panic_info| {
+            Self::handle_panic(panic_info);
+            previous_panic_hook(panic_info);
+            std::process::exit(1);
+        }));
         my.begin();
+        my.try_resize(width, height);
         my
     }
 
@@ -113,9 +118,24 @@ impl ConsoleEngine {
     /// Initialize a screen filling the entire terminal with the target FPS  
     /// Also check the terminal width and height and assert if the terminal has at least the asked size
     pub fn init_fill_require(width: u32, height: u32, target_fps: u32) -> ConsoleEngine {
+        let mut my = ConsoleEngine::init_fill(target_fps);
+        my.try_resize(width, height);
+        my
+    }
+
+    /// Try to resize the terminal to match the asked width and height at minimum
+    fn try_resize(&mut self, width: u32, height: u32) {
         let size = crossterm::terminal::size().unwrap();
-        assert!(size.0 as u32 >= width && size.1 as u32 >= height, "Your terminal must have at least a width and height of {}x{} characters. Currently has {}x{}", width, height, size.0, size.1);
-        ConsoleEngine::init_fill(target_fps)
+        if (size.0 as u32) < width || (size.1 as u32) < height {
+            execute!(self.stdout, 
+                crossterm::terminal::SetSize(width as u16, height as u16),
+                crossterm::terminal::SetSize(width as u16, height as u16)
+            ).ok();
+            self.resize(width, height);
+        }
+        if crossterm::terminal::size().unwrap() < (width as u16, height as u16) {
+            panic!("Your terminal must have at least a width and height of {}x{} characters. Currently has {}x{}", width, height, size.0, size.1)
+        }
     }
 
     /// Initializes the internal components such as hiding the cursor
@@ -123,8 +143,8 @@ impl ConsoleEngine {
         terminal::enable_raw_mode().unwrap();
         execute!(
             self.stdout,
-            terminal::Clear(ClearType::All),
             terminal::EnterAlternateScreen,
+            terminal::Clear(ClearType::All),
             crossterm::cursor::Hide,
             crossterm::cursor::MoveTo(0, 0),
             crossterm::event::EnableMouseCapture
@@ -146,6 +166,26 @@ impl ConsoleEngine {
         terminal::disable_raw_mode().unwrap();
     }
 
+    fn handle_panic(_panic_info: &std::panic::PanicInfo) {
+        execute!(
+            stdout(),
+            crossterm::cursor::Show,
+            style::SetBackgroundColor(Color::Reset),
+            style::SetForegroundColor(Color::Reset),
+            crossterm::event::DisableMouseCapture,
+            terminal::LeaveAlternateScreen
+        )
+        .unwrap();
+        terminal::disable_raw_mode().unwrap();
+    }
+
+    /// Set the terminal's title
+    pub fn set_title(&mut self, title: &str) {
+        execute!(self.stdout,
+            crossterm::terminal::SetTitle(title)
+        ).ok();
+    } 
+
     /// Get the screen width
     pub fn get_width(&self) -> u32 {
         self.screen.get_width()
@@ -373,6 +413,20 @@ impl ConsoleEngine {
         self.screen_last_frame = Screen::new_empty(self.width, self.height);
     }
 
+    /// Extracts part of the current screen as a separate Screen object
+    /// The original screen is not altered
+    /// If the coordinates are out of bounds, they'll be replace by the `default` pixel
+    /// 
+    /// usage:
+    /// ```
+    /// use console_engine::pixel;
+    /// // extract a 3x2 screen from the engine screen
+    /// let scr_chunk = engine.extract(10, 4, 12, 5, pixel::pxl(' '));
+    /// ```
+    pub fn extract(&self, start_x: i32, start_y: i32, end_x: i32, end_y: i32, default: Pixel) -> Screen {
+        self.screen.extract(start_x, start_y, end_x, end_y, default)
+    }
+
     /// Changes the screen instance used by the engine and updates internal informations
     ///
     /// Useful if you want to manage multiple screens independently.
@@ -791,4 +845,4 @@ impl Drop for ConsoleEngine {
     fn drop(&mut self) {
         self.end();
     }
-}
+}
\ No newline at end of file
